@@ -31,7 +31,7 @@ async def get_user_id_or_none(request: Request) -> str | None:
 
     user_id = token_payload.get("user_id")
 
-    if not await admin_model.get_obj(user_id):
+    if not user_id or not await admin_model.get_obj(user_id):
         return None
 
     return user_id
